@@ -4,7 +4,10 @@ suppressPackageStartupMessages(library("dplyr"))
 packageVersion("dplyr")
 library("replyr")
 packageVersion("replyr")
-execute_vignette <- requireNamespace("RSQLite", quietly = TRUE)
+execute_vignette <- requireNamespace("RSQLite", quietly = TRUE) &&
+  requireNamespace("igraph", quietly = TRUE) &&
+  requireNamespace("DiagrammeR", quietly = TRUE) &&
+  requireNamespace("webshot", quietly = TRUE)
 
 ## ----data, eval=execute_vignette-----------------------------------------
 # load notional example data
@@ -96,7 +99,7 @@ if(!is.null(inspectDescrAndJoinPlan(tDesc, columnJoinPlan))) {
 print(columnJoinPlan %>% 
         select(tableName, sourceColumn, resultColumn, isKey, want))
 
-## ----diagram, eval=execute_vignette--------------------------------------
+## ----diagram, eval=execute_vignette, error=TRUE--------------------------
 columnJoinPlan %.>%
   makeJoinDiagramSpec(.) %.>%
   DiagrammeR::grViz(.)
